@@ -2,16 +2,20 @@
 from typing import Any, Dict, List, Tuple
 
 # Local Folder
+from .models.query import Query
 from .service import OctoxLabsService
 from .models.discovery import Discovery
-from .exceptions import NoDiscoveryError
 from .models.adapter import Adapter, Connection
+from .exceptions import NotFound, NoDiscoveryError
 from .constants.paths import (
+    queries_path,
     adapters_path,
+    ping_pong_path,
     connections_path,
     discoveries_path,
-    asset_detail_path,
-    asset_search_path,
+    query_detail_path,
+    device_detail_path,
+    device_search_path,
     last_discovery_path,
 )
 
@@ -22,6 +26,12 @@ class OctoxLabs:
     def __init__(self, ip: str, token: str):
         self.service = OctoxLabsService(ip=ip, token=token)
 
+    def ping(self):
+        response = self.service.request_builder(path=ping_pong_path()).json()
+        if response.get("pong", None) == "ok":
+            return True
+        return False
+
     def get_adapters(self, search: str = "", size: int = 100, page: int = 1) -> Tuple[int, List[Adapter]]:
         adapters_data = self.service.request_builder(
             path=adapters_path(), params={"search": search, "size": size, "page": page}
@@ -85,7 +95,7 @@ class OctoxLabs:
             )
         raise NoDiscoveryError("No discovery.")
 
-    def search_assets(
+    def search_devices(
         self,
         query: str = "",
         fields: List[str] = None,
@@ -103,13 +113,56 @@ class OctoxLabs:
             "index_id": discovery.id if discovery else discovery_id or None,
             "ordering": ordering or [],
         }
-        data = self.service.request_builder(method="POST", path=asset_search_path(), json=payload).json()
+        data = self.service.request_builder(method="POST", path=device_search_path(), json=payload).json()
         return data.get("count"), data.get("results")
 
-    def get_asset_detail(
+    def get_device_detail(
         self, hostname: str, discovery: Discovery = None, discovery_id: int = None
     ) -> Dict[str, List[Any]]:
         payload = {"index_id": discovery.id if discovery else discovery_id or self.get_last_discovery().id}
         return self.service.request_builder(
-            method="POST", path=asset_detail_path(hostname=hostname), json=payload
+            method="POST", path=device_detail_path(hostname=hostname), json=payload
         ).json()
+
+    def get_queries(self, page: int = 1, search: str = "", size: int = 20) -> Tuple[int, List[Query]]:
+        payload = {"page": page, "search": search, "size": size}
+        queries_data = self.service.request_builder(path=queries_path(), params=payload).json()
+        return queries_data.get("count"), [
+            Query(
+                id=query.get("id"),
+                name=query.get("name"),
+                text=query.get("text"),
+                tags=query.get("tags"),
+                count=query.get("count"),
+                is_public=query.get("is_public"),
+                created_at=query.get("created_at"),
+                updated_at=query.get("updated_at"),
+                username=query.get("user_full_name"),
+                is_temporary=query.get("temporary"),
+                service=self.service,
+            )
+            for query in queries_data.get("results")
+        ]
+
+    def get_query_by_id(self, query_id: int) -> Query:
+        query = self.service.request_builder(path=query_detail_path(query_id=query_id)).json()
+        return Query(
+            id=query.get("id"),
+            name=query.get("name"),
+            text=query.get("text"),
+            tags=query.get("tags"),
+            count=query.get("count"),
+            is_public=query.get("is_public"),
+            created_at=query.get("created_at"),
+            updated_at=query.get("updated_at"),
+            username=query.get("user_full_name"),
+            is_temporary=query.get("temporary"),
+            service=self.service,
+        )
+
+    def get_query_by_name(self, query_name: str) -> Query:
+        _, queries = self.get_queries(search=query_name, size=1000)
+        for query in queries:
+            if query_name == query.name:
+                return query
+        raise NotFound("Query not found.")
